import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoT1ClickDevicesServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoT1ClickDevicesServiceClient";
import { ClaimDevicesByClaimCodeRequest, ClaimDevicesByClaimCodeResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ClaimDevicesByClaimCodeCommand}.
 */
export interface ClaimDevicesByClaimCodeCommandInput extends ClaimDevicesByClaimCodeRequest {
}
/**
 * @public
 *
 * The output of {@link ClaimDevicesByClaimCodeCommand}.
 */
export interface ClaimDevicesByClaimCodeCommandOutput extends ClaimDevicesByClaimCodeResponse, __MetadataBearer {
}
declare const ClaimDevicesByClaimCodeCommand_base: {
    new (input: ClaimDevicesByClaimCodeCommandInput): import("@smithy/smithy-client").CommandImpl<ClaimDevicesByClaimCodeCommandInput, ClaimDevicesByClaimCodeCommandOutput, IoT1ClickDevicesServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: ClaimDevicesByClaimCodeCommandInput): import("@smithy/smithy-client").CommandImpl<ClaimDevicesByClaimCodeCommandInput, ClaimDevicesByClaimCodeCommandOutput, IoT1ClickDevicesServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Adds device(s) to your account (i.e., claim one or more devices) if and only if you
 *  received a claim code with the device(s).</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoT1ClickDevicesServiceClient, ClaimDevicesByClaimCodeCommand } from "@aws-sdk/client-iot-1click-devices-service"; // ES Modules import
 * // const { IoT1ClickDevicesServiceClient, ClaimDevicesByClaimCodeCommand } = require("@aws-sdk/client-iot-1click-devices-service"); // CommonJS import
 * const client = new IoT1ClickDevicesServiceClient(config);
 * const input = { // ClaimDevicesByClaimCodeRequest
 *   ClaimCode: "STRING_VALUE", // required
 * };
 * const command = new ClaimDevicesByClaimCodeCommand(input);
 * const response = await client.send(command);
 * // { // ClaimDevicesByClaimCodeResponse
 * //   ClaimCode: "STRING_VALUE",
 * //   Total: Number("int"),
 * // };
 *
 * ```
 *
 * @param ClaimDevicesByClaimCodeCommandInput - {@link ClaimDevicesByClaimCodeCommandInput}
 * @returns {@link ClaimDevicesByClaimCodeCommandOutput}
 * @see {@link ClaimDevicesByClaimCodeCommandInput} for command's `input` shape.
 * @see {@link ClaimDevicesByClaimCodeCommandOutput} for command's `response` shape.
 * @see {@link IoT1ClickDevicesServiceClientResolvedConfig | config} for IoT1ClickDevicesServiceClient's `config` shape.
 *
 * @throws {@link ForbiddenException} (client fault)
 *
 * @throws {@link InternalFailureException} (server fault)
 *
 * @throws {@link InvalidRequestException} (client fault)
 *
 * @throws {@link IoT1ClickDevicesServiceServiceException}
 * <p>Base exception class for all service exceptions from IoT1ClickDevicesService service.</p>
 *
 * @public
 */
export declare class ClaimDevicesByClaimCodeCommand extends ClaimDevicesByClaimCodeCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ClaimDevicesByClaimCodeRequest;
            output: ClaimDevicesByClaimCodeResponse;
        };
        sdk: {
            input: ClaimDevicesByClaimCodeCommandInput;
            output: ClaimDevicesByClaimCodeCommandOutput;
        };
    };
}
