import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoT1ClickDevicesServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoT1ClickDevicesServiceClient";
import { GetDeviceMethodsRequest, GetDeviceMethodsResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetDeviceMethodsCommand}.
 */
export interface GetDeviceMethodsCommandInput extends GetDeviceMethodsRequest {
}
/**
 * @public
 *
 * The output of {@link GetDeviceMethodsCommand}.
 */
export interface GetDeviceMethodsCommandOutput extends GetDeviceMethodsResponse, __MetadataBearer {
}
declare const GetDeviceMethodsCommand_base: {
    new (input: GetDeviceMethodsCommandInput): import("@smithy/smithy-client").CommandImpl<GetDeviceMethodsCommandInput, GetDeviceMethodsCommandOutput, IoT1ClickDevicesServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: GetDeviceMethodsCommandInput): import("@smithy/smithy-client").CommandImpl<GetDeviceMethodsCommandInput, GetDeviceMethodsCommandOutput, IoT1ClickDevicesServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Given a device ID, returns the invokable methods associated with the device.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoT1ClickDevicesServiceClient, GetDeviceMethodsCommand } from "@aws-sdk/client-iot-1click-devices-service"; // ES Modules import
 * // const { IoT1ClickDevicesServiceClient, GetDeviceMethodsCommand } = require("@aws-sdk/client-iot-1click-devices-service"); // CommonJS import
 * const client = new IoT1ClickDevicesServiceClient(config);
 * const input = { // GetDeviceMethodsRequest
 *   DeviceId: "STRING_VALUE", // required
 * };
 * const command = new GetDeviceMethodsCommand(input);
 * const response = await client.send(command);
 * // { // GetDeviceMethodsResponse
 * //   DeviceMethods: [ // __listOfDeviceMethod
 * //     { // DeviceMethod
 * //       DeviceType: "STRING_VALUE",
 * //       MethodName: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param GetDeviceMethodsCommandInput - {@link GetDeviceMethodsCommandInput}
 * @returns {@link GetDeviceMethodsCommandOutput}
 * @see {@link GetDeviceMethodsCommandInput} for command's `input` shape.
 * @see {@link GetDeviceMethodsCommandOutput} for command's `response` shape.
 * @see {@link IoT1ClickDevicesServiceClientResolvedConfig | config} for IoT1ClickDevicesServiceClient's `config` shape.
 *
 * @throws {@link InternalFailureException} (server fault)
 *
 * @throws {@link InvalidRequestException} (client fault)
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *
 * @throws {@link IoT1ClickDevicesServiceServiceException}
 * <p>Base exception class for all service exceptions from IoT1ClickDevicesService service.</p>
 *
 * @public
 */
export declare class GetDeviceMethodsCommand extends GetDeviceMethodsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetDeviceMethodsRequest;
            output: GetDeviceMethodsResponse;
        };
        sdk: {
            input: GetDeviceMethodsCommandInput;
            output: GetDeviceMethodsCommandOutput;
        };
    };
}
