import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoT1ClickDevicesServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoT1ClickDevicesServiceClient";
import { UnclaimDeviceRequest, UnclaimDeviceResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link UnclaimDeviceCommand}.
 */
export interface UnclaimDeviceCommandInput extends UnclaimDeviceRequest {
}
/**
 * @public
 *
 * The output of {@link UnclaimDeviceCommand}.
 */
export interface UnclaimDeviceCommandOutput extends UnclaimDeviceResponse, __MetadataBearer {
}
declare const UnclaimDeviceCommand_base: {
    new (input: UnclaimDeviceCommandInput): import("@smithy/smithy-client").CommandImpl<UnclaimDeviceCommandInput, UnclaimDeviceCommandOutput, IoT1ClickDevicesServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: UnclaimDeviceCommandInput): import("@smithy/smithy-client").CommandImpl<UnclaimDeviceCommandInput, UnclaimDeviceCommandOutput, IoT1ClickDevicesServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Disassociates a device from your AWS account using its device ID.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoT1ClickDevicesServiceClient, UnclaimDeviceCommand } from "@aws-sdk/client-iot-1click-devices-service"; // ES Modules import
 * // const { IoT1ClickDevicesServiceClient, UnclaimDeviceCommand } = require("@aws-sdk/client-iot-1click-devices-service"); // CommonJS import
 * const client = new IoT1ClickDevicesServiceClient(config);
 * const input = { // UnclaimDeviceRequest
 *   DeviceId: "STRING_VALUE", // required
 * };
 * const command = new UnclaimDeviceCommand(input);
 * const response = await client.send(command);
 * // { // UnclaimDeviceResponse
 * //   State: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param UnclaimDeviceCommandInput - {@link UnclaimDeviceCommandInput}
 * @returns {@link UnclaimDeviceCommandOutput}
 * @see {@link UnclaimDeviceCommandInput} for command's `input` shape.
 * @see {@link UnclaimDeviceCommandOutput} for command's `response` shape.
 * @see {@link IoT1ClickDevicesServiceClientResolvedConfig | config} for IoT1ClickDevicesServiceClient's `config` shape.
 *
 * @throws {@link InternalFailureException} (server fault)
 *
 * @throws {@link InvalidRequestException} (client fault)
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *
 * @throws {@link IoT1ClickDevicesServiceServiceException}
 * <p>Base exception class for all service exceptions from IoT1ClickDevicesService service.</p>
 *
 * @public
 */
export declare class UnclaimDeviceCommand extends UnclaimDeviceCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: UnclaimDeviceRequest;
            output: UnclaimDeviceResponse;
        };
        sdk: {
            input: UnclaimDeviceCommandInput;
            output: UnclaimDeviceCommandOutput;
        };
    };
}
